"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const log_1 = require("../common/log");
const util_1 = require("../common/util");
const child_process_1 = require("child_process");
const fs_1 = require("fs");
exports.command = "test";
exports.desc = "单元测试";
exports.builder = (yargs) => {
    return yargs
        .option("p", {
        alias: "path",
        describe: "测试的目录",
        default: ".",
        type: "string"
    })
        .usage("Usage: $0 test -p .");
};
exports.handler = (yargs) => {
    let projectPath = path.resolve(yargs.p) || process.cwd();
    test(projectPath);
    coveralls(projectPath);
};
function test(projectPath) {
    log_1.printMessage("单元测试开始...");
    let nyc = util_1.getCreateProjectDependencies(projectPath, path.join("nyc", "bin", "nyc.js"));
    let mocha = util_1.getCreateProjectDependencies(projectPath, path.join("mocha", "bin", "mocha"));
    let options = {
        encoding: "utf8",
        cwd: projectPath,
        stdio: [process.stdin, process.stdout, process.stderr]
    };
    console.log('test', mocha);
    let childProcess = child_process_1.spawnSync(nyc, [mocha, "-t", "5000"], options);
    if (childProcess.status !== 0) {
        log_1.printErrorMessage(childProcess.error.message);
        log_1.printErrorMessage("单元测试失败！");
        process.exit(childProcess.status);
        return;
    }
    log_1.printMessage("单元测试成功结束");
}
function coveralls(projectPath) {
    log_1.printMessage("覆盖率开始...");
    let nycrcFile = path.join(projectPath, ".nycrc");
    fs_1.writeFileSync(nycrcFile, `{
  "include": [
    "src/**/*.ts"
  ],
  "extension": [
    ".ts"
  ],
  "require": [
    "ts-node/register"
  ],
  "sourceMap": true,
  "instrument": true
}`.trim());
    let nyc = util_1.getCreateProjectDependencies(projectPath, path.join("nyc", "bin", "nyc.js"));
    let coveralls = util_1.getCreateProjectDependencies(projectPath, path.join("coveralls", "bin", "coveralls.js"));
    let commandText = `"${nyc}" mocha -t 5000 && "${nyc}" report --reporter=text-lcov | "${coveralls}"`;
    let res = child_process_1.execSync(commandText, { encoding: "utf-8", cwd: projectPath });
    fs_1.unlinkSync(nycrcFile);
    log_1.printMessage("覆盖率完成");
}
//# sourceMappingURL=test.js.map